==> mythplugins-0.19.tar.bz2: mythplugins-0.19/mythgame/i18n/mythgame_ca.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GameTree</name>
    <message>
        <source>All Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-   By Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-   By Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-   By Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Players Available. 

 Please pick one.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MythGamePlayerEditor</name>
    <message>
        <source>Game Player Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit..</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete..</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this item?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes, delete It</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No, don&apos;t</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Game display order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGame Settings -- General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order in which to sort the games - this is for all systems. Available choices: system, year, genre and gamename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favourite display order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order in which to sort the games marked as favourites - this is for all systems. Available choices: system, year, genre and gamename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indepth Game Scan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabling this causes a game scan to gather crc values and attempt to find out more detailed information about the game: NOTE this can greatly increase the time a gamescan takes based on the amount of games scanned.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prompt for removal of deleted rom(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This enables a prompt for removing deleted roms from the database during a  gamescan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Files Names in Game Tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabling this causes the filenames to be displayed in the game tree rather than the trimmed/looked up gamename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow games to span multiple roms/disks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This setting means that we will look for items like game.1.rom, game.2.rom and consider them a single game.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path+name of binary and optional parameters. %s can be used to represent the name of any rom being launched. if not specified the rom filename will be added to the end of the command. As well %d1, %d2, %d3 and %d4 represent disks in a multidisk/game situation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type of Game/Emulator. Mostly for informational purposes and has little effect on the function of your system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rom Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location of the ROM files for this emulator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Working Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory to change to before launching emulator. Blank is usually fine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List of all file extensions to be used for this emulator. Blank means any file under ROM PATH is considered to be used with this emulator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ScreenShots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path to any screenshots for this player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Player Setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(New Game Player)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NES</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SNES</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N64</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCE/TG16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GENESIS/MEGADRIVE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PC GAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AMIGA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ATARI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name of this Game and or Emulator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>19xx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No to all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes to all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 appears to be missing.
Remove it from the database?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will clear all Game Meta Data
from the database. Are you sure you
want to do this?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEGA/MASTER SYSYTEM</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>System:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mythplugins-0.23.tar.bz2: mythplugins-0.23/mythgame/i18n/mythgame_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>GameUI</name>
    <message>
        <source>All Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-   By Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-   By Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-   By Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-   By Publisher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose System for</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MythControls</name>
    <message>
        <source>Game frontend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle the current game as a favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show incremental search dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Incremental search find next match</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MythGamePlayerEditor</name>
    <message>
        <source>Game Player Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit..</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete..</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this item?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes, delete It</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No, don&apos;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Players</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Game display order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGame Settings -- General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order in which to sort the games - this is for all systems. Available choices: system, year, genre and gamename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favourite display order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order in which to sort the games marked as favourites - this is for all systems. Available choices: system, year, genre and gamename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indepth Game Scan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabling this causes a game scan to gather crc values and attempt to find out more detailed information about the game: NOTE this can greatly increase the time a gamescan takes based on the amount of games scanned.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prompt for removal of deleted rom(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This enables a prompt for removing deleted roms from the database during a  gamescan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Files Names in Game Tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabling this causes the filenames to be displayed in the game tree rather than the trimmed/looked up gamename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow games to span multiple roms/disks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This setting means that we will look for items like game.1.rom, game.2.rom and consider them a single game.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type of Game/Emulator. Mostly for informational purposes and has little effect on the function of your system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rom Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location of the ROM files for this emulator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Working Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory to change to before launching emulator. Blank is usually fine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Player Setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(New Game Player)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NES</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SNES</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N64</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCE/TG16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GENESIS/MEGADRIVE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PC GAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AMIGA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ATARI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name of this Game and or Emulator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>19xx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No to all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes to all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 appears to be missing.
Remove it from the database?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will clear all Game Meta Data
from the database. Are you sure you
want to do this?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEGA/MASTER SYSYTEM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Comma seperated list of all file extensions for this emulator. Blank means any file under ROM PATH is considered to be used with this emulator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GAMEGEAR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updating %1(%2) ROM database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Verifying %1 files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scanning for %1 game(s)...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hash filenames in display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable hashing of names in the display tree. This can make navigating long lists a little faster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Binary and optional parameters. Multiple commands seperated with &apos;;&apos; . Use %s for the rom name. %d1, %d2, %d3 and %d4 represent disks in a multidisk/game. %s auto appended if not specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory where Game Screenshots are stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory will be the default browse location when assigning screenshots.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory where Game Fanart is stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory will be the default browse location when assigning fanart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory where Game Boxart is stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory will be the default browse location when assigning boxart.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>System:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Game Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Country:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Publisher:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plot:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshot:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fanart:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boxart:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>/path/to/the/thing.jpg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rompath:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System(s):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CRC:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Plot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Players</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan for Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Game Data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
